Authors
================

* Matthew Westcott matthew.westcott@torchbox.com twitter: @gasmanic
* David Cranwell david.cranwell@torchbox.com twitter: @davecranwell
* Karl Hobley karl.hobley@torchbox.com

Contributors
============

* Helen Chapman helen.chapman@torchbox.com
* Balazs Endresz balazs.endresz@torchbox.com
* Neal Todd neal.todd@torchbox.com
* Paul Hallett (twilio) hello@phalt.co
* Tom Dyson
* Serafeim Papastefanos
* Łukasz Bołdys
* peterarenot
* Levi Gross
* Delgermurun Purevkhuu
* Lewis Cowper
* Stephen Newey
* Ryan Foster
* v1kku
* Miguel Vieira
* Ben Emery
* David Smith
* Ben Margolis
* Tom Talbot
* Jeffrey Hearn
* Robert Clark
* Tim Heap
* Nathan Brizendine
* thenewguy
* John-Scott Atlakson
* Eric Drechsel
* Alejandro Giacometti
* Robert Rollins
* linibou
* Timo Rieber
* Jerel Unruh
* georgewhewell
* Frank Wiles
* Sebastian Spiegel
* Alejandro Varas
* Martin Sanders
* Benoît Bar
* Claudemiro
* Tiago Henriques
* Arne Schauf
* Jordi Joan
* Damian Moore
* signalkraft
* Mac Chapman

Translators
===========

* Basque: Unai Zalakain
* Bulgarian: Lyuboslav Petrov
* Catalan: David Llop
* Chinese: Victoria Chan, Leway Colin, hanfeng, qiulin, Tulpar Turamat, wwj718
* Chinese (China): hanfeng, Lihan Li, ufoym
* Chinese (Taiwan): wdv4758h, jshc
* Czech: Jiri Stepanek
* Dutch: t.vandemeer, mahulst, Samuel Leeuwenburg
* French: Sylvain Fankhauser, sephii, Adrihein, Bertrand Bordage, Romain Hardouin, linibou, nahuel, Benoît Bar
* Galician: fooflare, fonso
* German: Karl Sander, Johannes Spielmann, m0rph3u5, pcraston
* Greek: Serafeim Papastefanos, Jim Dal
* Italian: Andrea Tagliazucchi
* Japanese: Daigo Shitara, Toshikazu Michisu
* Mongolian: Delgermurun Purevkhuu, miiiga
* Polish: Łukasz Bołdys
* Portuguese (Brazil): Gilson Filho, Douglas Miranda, Thiago Cangussu, João Luiz Lorencetti, Gladson Brito, Marcelo J. Both
* Portuguese (Portugal): Jose Lourenco, Tiago Henriques
* Romanian: Dan Braghis
* Russian: ice9, HNKNTA, MechanisM, Andrey Tykhonov, Kirill Drozdov, Liliana Kastilio, Sergey Komarov
* Spanish: Unai Zalakain, fooflare, Yusuf (Josè) Luis
* Ukrainian: Andrey Tykhonov, Mykola Zamkovoi
* Vietnamese: binhle, Luan Nguyen
